@@ -3,7 +3,7 @@ use strict;
 
 package RT::Extension::RepeatTicket;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 use RT::Interface::Web;
 use DateTime;
@@ -11,6 +11,9 @@ use RT::Date;
 use List::MoreUtils qw/after/;
 use DateTime::Event::ICal;
 
+RT->AddStyleSheets('repeat-ticket.css')
+    if $RT::StaticPath;
+
 my $old_create_ticket = \&HTML::Mason::Commands::CreateTicket;
 {
     no warnings 'redefine';
